"""Project file for mongodb."""
import typing as tp

import benchbuild as bb
from benchbuild.utils.cmd import python3
from benchbuild.utils.settings import get_number_of_jobs
from plumbum import local

from varats.paper_mgmt.paper_config import project_filter_generator
from varats.project.project_util import (
    ProjectBinaryWrapper,
    wrap_paths_to_binaries,
    BinaryType,
)
from varats.provider.cve.cve_provider import CVEProviderHook
from varats.utils.settings import bb_cfg


class MongoDB(bb.Project, CVEProviderHook):  # type: ignore
    """
    MongoDB is a cross-platform document-oriented database program.

    Classified as a NoSQL database program, MongoDB uses JSON-like documents
    with optional schemas.
    """

    NAME = 'mongodb'
    GROUP = 'cpp_projects'
    DOMAIN = 'database'

    SOURCE = [
        bb.source.Git(
            remote="https://github.com/mongodb/mongo.git",
            local="mongodb",
            refspec="HEAD",
            limit=None,
            shallow=False,
            version_filter=project_filter_generator("mongodb")
        )
    ]

    @property
    def binaries(self) -> tp.List[ProjectBinaryWrapper]:
        """Return a list of binaries generated by the project."""
        # TODO: please add correct binary names
        return wrap_paths_to_binaries([("MISSING", BinaryType.executable)])

    def run_tests(self) -> None:
        pass

    def compile(self) -> None:
        """Compile the project."""
        mongodb_version_source = local.path(self.source_of(self.primary_source))

        c_compiler = bb.compiler.cc(self)  # type: ignore
        cxx_compiler = bb.compiler.cxx(self)  # type: ignore
        with local.cwd(mongodb_version_source):
            with local.env(CC=str(c_compiler), CXX=str(cxx_compiler)):
                bb.watch(python3)(  # type: ignore
                    "buildscripts/scons.py",
                    f"-j {get_number_of_jobs(bb_cfg())}", "-d",
                    "--disable-warnings-as-errors"
                )

    @classmethod
    def get_cve_product_info(cls) -> tp.List[tp.Tuple[str, str]]:
        return [("Mongodb", "Mongodb")]
